.. Copyright (C) 2012, Christof Buchbender
.. BSD Licencse

Astrolyze
#########

Astrolyze is a python-package with several functions for reduction and analysis
of (mainly) radioastronomical data analysis. It is developed over the course of
my Diploma and PhD thesis. I decided to package the functions because I think
that they may be useful to other astronomers. The package is open for
collaboration.


.. image:: https://img.shields.io/badge/documented-here-brightgreen.svg
    :target: http://astrolyze.readthedocs.org/en/latest/index.html
    :alt: Status
